# User Guide

This guide provides an overview of SweetBean features.

## Features

- **Declarative Specification**: SweetBean is a domain-specific programming language in Python built for the declarative
  specification of stimuli sequences that can be synthesized into JavaScript or HTML files ready to be served as online
  or run with Large Language Models or Vision Models as synthetic participants.
- SweetBean experiments can be exported to multiple formats:
    - **HTML**: SweetBean can export experiments to HTML files that can be served as online experiments.
    - **JavaScript**: SweetBean can export experiments to JavaScript files that can be run in the browser.
    - **AutoRA**: SweetBean can be used to run automated Experiments
      with [AutoRA](https://autoresearch.github.io/autora/).
    - **LLM**: SweetBean can be used to run experiments with Large Language Models.
    - Coming soon: **Vision Models**: SweetBean can be used to run experiments with Vision Models.


